"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const helper_functions_1 = require("../config/helper-functions");
const sigma_configuration_1 = require("../config/sigma-configuration");
class Conf extends core_1.Command {
    constructor() {
        super(...arguments);
        this.TestHost = "https://connect.test.krucial.cloud";
        this.ProdHost = "https://connect.krucial.cloud";
        this.LocalDevelopment = "local development";
    }
    async run() {
        let flags;
        const helperFunctions = new helper_functions_1.default();
        try {
            await this.parse(Conf).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            if (Object.getOwnPropertyNames(flags).length === 0) {
                console.log("You have not passed any flags to this command. Please use --help to see command usage.");
                return;
            }
            if (flags.clientSecret && flags.clientId) {
                let conf = {
                    clientId: flags.clientId,
                    clientSecret: flags.clientSecret
                };
                this.AddTargetToConfig(conf);
                helperFunctions.writeConfFile(conf);
                console.log("client id and secret set successfully.");
            }
            if (flags.show) {
                let data = helperFunctions.readConfFile(helperFunctions.ConfigFilePath);
                console.log(data);
            }
            return;
        }
        catch (err) {
            const error = err;
            console.log(error.message);
        }
    }
    AddTargetToConfig(conf) {
        let host = "";
        const sigmaConfig = new sigma_configuration_1.default().BaseApiPath;
        //check for dev env
        if (sigmaConfig.includes("localhost")) {
            host = this.LocalDevelopment;
        }
        //check for deployed env
        else if (sigmaConfig.includes("test")) {
            host = this.TestHost;
        }
        else {
            host = this.ProdHost;
        }
        conf.target = host;
        return conf;
    }
}
exports.default = Conf;
Conf.description = "Get or set configuration values.";
Conf.examples = [
    "<%= config.bin %> <%= command.id %> --show",
    "<%= config.bin %> <%= command.id %> --clientId MyClientId --clientSecret MyClientSecret"
];
Conf.flags = {
    show: core_1.Flags.boolean({ char: "s", description: "Show configuration values.", required: false }),
    clientId: core_1.Flags.string({ description: "Client Id to set.", required: false }),
    clientSecret: core_1.Flags.string({ description: "Client Secret to set.", required: false })
};
