"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
const endpoints_1 = require("../../endpoints");
class Post extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(Post).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const base_api = new sigma_api_builder_1.default().buildApi("plugin");
            let authType = flags.authType;
            let createPluginDto;
            createPluginDto = {
                pluginName: flags.name,
                pluginType: flags.pluginType,
                authType: flags.authType,
                authentication: undefined
            };
            //check if the auth type is not None - and add the authentication to the CreatePluginDto
            if (authType !== endpoints_1.PluginAuthenticationTypeEnum.None && authType !== "None") {
                createPluginDto.authentication = {
                    clientId: flags.clientId,
                    clientSecret: flags.clientSecret,
                    authEndpoint: flags.authEndpoint
                };
                if (flags.validateClientCredentials) {
                    createPluginDto.validateClientCredentials = flags.validateClientCredentials;
                }
            }
            if (authType !== endpoints_1.PluginAuthenticationTypeEnum.None && authType !== "None" && flags.clientId === null
                && flags.clientSecret === null && flags.authEndpoint === null) {
                console.log(`You've tried to create a plugin with authentication. Please ensure that the clientId, clientSecret
        and authEndpoint fields are all populated. Or use 0 as the authType to create a plugin with no authentication.`);
                return;
            }
            base_api.v1PluginPost(createPluginDto).then((res) => {
                console.log(`Plugin with name ${createPluginDto.pluginName} successfully created.`);
                if (res.data != "") {
                    console.log(res.data);
                }
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = Post;
Post.description = "Create a new plugin.";
Post.examples = [
    "<%= config.bin %> <%= command.id %> --name NewName --pluginType iTwin --authType none",
    "<%= config.bin %> <%= command.id %> --name NewName --pluginType iTwin --authType oAuth " +
        "--authEndpoint \"https://cli.krucial.auth\" --clientId myClientId --clientSecret myClientSecret",
    "<%= config.bin %> <%= command.id %> --name NewName --pluginType iTwin --authType oAuth " +
        "--authEndpoint \"https://cli.krucial.auth\" --clientId myClientId --clientSecret myClientSecret --validateClientSecret"
];
Post.flags = {
    name: core_1.Flags.string({ char: "n", description: "Name for new plugin.", required: true }),
    pluginType: core_1.Flags.string({ char: "t", description: "Type for new plugin.", required: true }),
    authType: core_1.Flags.string({ char: "a", description: "Authentication for new plugin.", required: true }),
    clientId: core_1.Flags.string({ char: "i", description: "Client Id for OAuth authentication.", required: false }),
    clientSecret: core_1.Flags.string({ char: "s", description: "Client Secret for OAuth authentication.", required: false }),
    authEndpoint: core_1.Flags.string({ char: "e", description: "Endpoint to hit for OAuth authentication.", required: false }),
    validateClientCredentials: core_1.Flags.boolean({ char: "v", description: "Validate your client credentials against the given auth endpoint",
        required: false })
};
