"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class DeleteDevice extends core_1.Command {
    async run() {
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("deployment");
        try {
            await this.parse(DeleteDevice).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const name = flags.name;
            const devEui = flags.devEui;
            let devicesToDelete = [];
            const devEuis = devEui.split(",").map((item) => item.trim());
            for (const d in devEuis) {
                devicesToDelete.push(devEuis[d]);
            }
            const removeDeviceFromDeploymentDto = { "deviceDevEuis": devicesToDelete };
            base_api.v1DeploymentNameDeviceDelete(name, removeDeviceFromDeploymentDto).then(() => {
                console.log(`Devices with ${devicesToDelete} successfully deleted from deployment with name ${name}.`);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = DeleteDevice;
DeleteDevice.description = "Delete device from deployment";
DeleteDevice.examples = [
    "<%= config.bin %> <%= command.id %> --name NameOfDeploymentToDeleteFrom --devEui 1111111111111111",
    "<%= config.bin %> <%= command.id %> --name NameOfDeploymentToDeleteFrom --devEui 1111111111111111,3333333333333333"
];
DeleteDevice.flags = {
    name: core_1.Flags.string({ char: "n", description: "Name of deployment.", required: true }),
    devEui: core_1.Flags.string({ char: "d", description: "DevEUI of device(s) to delete.",
        required: true })
};
