"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class GetDeviceData extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(GetDeviceData).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const deploymentName = flags.deploymentName;
            const devEui = flags.devEui;
            const startDateTime = flags.startDateTime;
            const endDateTime = flags.endDateTime;
            const base_api = new sigma_api_builder_1.default().buildApi("deployment");
            let api_call;
            if (devEui) {
                if (startDateTime || endDateTime) {
                    api_call = base_api.v1DeploymentNameDevicedataDevEuiGet(deploymentName, devEui, startDateTime, endDateTime);
                }
                api_call = base_api.v1DeploymentNameDevicedataDevEuiGet(deploymentName, devEui);
            }
            else {
                if (startDateTime || endDateTime) {
                    api_call = base_api.v1DeploymentNameDevicedataGet(deploymentName, startDateTime, endDateTime);
                }
                api_call = base_api.v1DeploymentNameDevicedataGet(deploymentName);
            }
            api_call.then((res) => {
                if (res.data != "") {
                    console.log(res.data);
                }
                else {
                    if (devEui) {
                        console.log(`No device data to display for deployment ${deploymentName} for device ${devEui}`);
                    }
                    console.log(`No device data to display for deployment ${deploymentName}`);
                }
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = GetDeviceData;
GetDeviceData.description = "Get all of the device data for a deployment. If the devEui is provided " +
    "retrieve data for the requested device. Date and time can also be used to further refine the data. " +
    "All Dates conform to UTC standard.";
GetDeviceData.examples = [
    "<%= config.bin %> <%= command.id %> --deploymentName MyTestDeployment",
    "<%= config.bin %> <%= command.id %> --deploymentName MyTestDeployment --devEui 2312121212121212",
    "<%= config.bin %> <%= command.id %> --deploymentName NameOfDeployment" +
        "--startDateTime \"2023-10-07 12:20:00\" --endDateTime \"2023-10-10 12:20:00\"",
    "<%= config.bin %> <%= command.id %> --deploymentName NameOfDeployment --devEui 2312121212121212 " +
        "--startDateTime \"2023-10-07 12:20:00\" --endDateTime \"2023-10-10 12:20:00\""
];
GetDeviceData.flags = {
    deploymentName: core_1.Flags.string({
        char: "n", description: "DeploymentName name to get data for all devices.",
        required: true
    }),
    devEui: core_1.Flags.string({ char: "d", description: "Get data for an individual device on that deployment." }),
    startDateTime: core_1.Flags.string({
        char: "s", description: "Get all data ahead of this date and time. " +
            "Passed in the following format: YYYY-MM-DD HH:MM:SS",
        required: false
    }),
    endDateTime: core_1.Flags.string({
        char: "e", description: "Get all data before this date and time. " +
            "Passed in the following format: YYYY-MM-DD HH:MM:SS",
        required: false
    })
};
