"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
class GetPluginConfig extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(GetPluginConfig).then((res) => {
                flags = res.flags;
            }).catch(() => {
                throw new Error("Flag passed is not supported.");
            });
            const deploymentName = flags.deploymentName;
            const pluginName = flags.pluginName;
            const base_api = new sigma_api_builder_1.default().buildApi("deployment");
            let api_call;
            if (pluginName) {
                api_call = base_api.v1DeploymentDeploymentNamePluginsPluginNameGet(deploymentName, pluginName);
            }
            else {
                api_call = base_api.v1DeploymentNamePluginsGet(deploymentName);
            }
            api_call.then((res) => {
                if (res.data === "") {
                    console.log("There are no plugins associated with your deployment.");
                    return;
                }
                console.log(res.data);
            }).catch((err) => {
                console.log(err.message);
            });
        }
        catch (err) {
            const error = err;
            console.log(error.message);
        }
    }
}
exports.default = GetPluginConfig;
GetPluginConfig.description = "Get plugin configuration for all plugins for a deployment. " +
    "Specifying the pluginName flag will retrieve configuration for the specified plugin.";
GetPluginConfig.examples = [
    "<%= config.bin %> <%= command.id %>",
    "<%= config.bin %> <%= command.id %> --name TestDeployment",
    "<%= config.bin %> <%= command.id %> --name TestDeployment --pluginName MyPluginName"
];
GetPluginConfig.flags = {
    deploymentName: core_1.Flags.string({ char: "d", description: "Deployment name.", required: true }),
    pluginName: core_1.Flags.string({ char: "p", description: "Plugin name.", required: false })
};
