"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
class Get extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(Get).then((res) => {
                flags = res.flags;
            }).catch(() => {
                throw new Error("Flag passed is not supported.");
            });
            const name = flags.name;
            const days = flags.days;
            const base_api = new sigma_api_builder_1.default().buildApi("deployment");
            let api_call;
            if (name && days) {
                api_call = base_api.v1DeploymentNameQueueDaysGet(name, days);
            }
            else if (name) {
                api_call = base_api.v1DeploymentNameGet(name);
            }
            else {
                api_call = base_api.v1DeploymentGet();
            }
            api_call.then((res) => {
                if (res.data === "") {
                    console.log("There are currently no deployments within your organisation.");
                    return;
                }
                console.log(res.data);
            }).catch((err) => {
                console.log(err.message);
            });
        }
        catch (err) {
            const error = err;
            console.log(error.message);
        }
    }
}
exports.default = Get;
Get.description = "Get all deployments. If name flag is set, get deployment by name.";
Get.examples = [
    "<%= config.bin %> <%= command.id %>",
    "<%= config.bin %> <%= command.id %> --name deploymentNameToGet"
];
Get.flags = {
    name: core_1.Flags.string({ char: "n", description: "Deployment name." }),
    days: core_1.Flags.string({ char: "d", description: "Number of days queue data to fetch." })
};
