"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class PostDevice extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(PostDevice).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const name = flags.name;
            const devEui = flags.devEui;
            const deviceProfileName = flags.deviceProfileName;
            const base_api = new sigma_api_builder_1.default().buildApi("deployment");
            let addDeviceToDeploymentDto = new Array;
            let addDevice = { "devEui": devEui, "deviceProfileName": deviceProfileName };
            addDeviceToDeploymentDto.push(addDevice);
            base_api.v1DeploymentNameDevicePost(name, addDeviceToDeploymentDto).then(() => {
                console.log(`Device with devEui ${devEui} and device profile ${deviceProfileName} successfully added to deployment ${name}.`);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = PostDevice;
PostDevice.description = "Create a new device on your deployment.";
PostDevice.examples = [
    "<%= config.bin %> <%= command.id %> --name NameOfDeployment --devEui DevEuiOfDevice " +
        "--deviceProfileName NameOfDeviceProfileForDevice"
];
PostDevice.flags = {
    name: core_1.Flags.string({ char: "n", description: "Name of deployment.", required: true }),
    devEui: core_1.Flags.string({ char: "d", description: "Dev EUI of new device.", required: true }),
    deviceProfileName: core_1.Flags.string({ char: "p", description: "Device profile for new device.", required: true })
};
