"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class Post extends core_1.Command {
    async run() {
        var _a;
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("deployment");
        try {
            await this.parse(Post).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const name = flags.name;
            let pluginNames = flags.pluginNames;
            if (pluginNames && (pluginNames.trim().length !== 0)) {
                pluginNames = pluginNames.split(",").map((item) => item.trim());
            }
            else {
                pluginNames = new Array();
            }
            const gateway = flags.serialNumber;
            const storeDataInternally = (_a = flags.dataStoreKrucialServers) !== null && _a !== void 0 ? _a : false;
            const createDeploymentJson = {
                "name": name, "gatewaySerialNumber": gateway, "pluginNames": pluginNames,
                "storeDataInternally": storeDataInternally
            };
            base_api.v1DeploymentPost(createDeploymentJson).then((res) => {
                if (pluginNames.toString() !== "") {
                    console.log(`Deployment with name ${name} created on gateway ${gateway} with plugins ${pluginNames}.`);
                }
                else {
                    console.log(`Deployment with name ${name} created on gateway ${gateway}.`);
                }
                if (res.data != "") {
                    console.log(res.data);
                }
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = Post;
Post.description = "Create a new deployment.";
Post.examples = [
    "<%= config.bin %> <%= command.id %> --name TestDeployment --serialNumber 12345 --dataStoreKrucialServers " +
        "--pluginNames \"MyPlugin1,MyPlugin2\"",
    "<%= config.bin %> <%= command.id %> --name TestDeployment --serialNumber 12345"
];
Post.flags = {
    name: core_1.Flags.string({ char: "n", description: "Name of new deployment.", required: true }),
    serialNumber: core_1.Flags.string({ char: "s", description: "Serial number of K-Cell.", required: true }),
    pluginNames: core_1.Flags.string({
        char: "p", description: "Name of plugins to be added in a comma seperated string.",
        required: false
    }),
    dataStoreKrucialServers: core_1.Flags.boolean({
        char: "d", description: "Store Deployment Data on Krucial Servers",
        required: false
    })
};
