"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class Put extends core_1.Command {
    async run() {
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("deployment");
        try {
            await this.parse(Put).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const name = flags.name;
            const serialNumber = flags.serialNumber;
            base_api.v1DeploymentNameGatewayPut(name, serialNumber).then(() => {
                console.log(`Gateway with serial number ${serialNumber} added to deployment ${name}.`);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = Put;
Put.description = "Replace a K-Cell in your deployment.";
Put.examples = [
    "<%= config.bin %> <%= command.id %> --name NameOfDeployment --serialNumber SerialNumberOfKCellToChangeTo"
];
Put.flags = {
    name: core_1.Flags.string({ char: "n", description: "Name of deployment to update.", required: true }),
    serialNumber: core_1.Flags.string({ char: "s", description: "Serial number of new K-Cell.", required: true })
};
