"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const fs_1 = require("fs");
const helper_functions_1 = require("../../config/helper-functions");
class Post extends core_1.Command {
    async run() {
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("device-profile");
        try {
            await this.parse(Post).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const deviceProfileFile = flags.deviceProfile;
            const codecFile = flags.codec;
            if (!deviceProfileFile.toLowerCase().match(".json")) {
                console.log("Error occurred processing device profile, the file must have a name ending in .json");
                return;
            }
            let deviceProfileFileData;
            try {
                deviceProfileFileData = JSON.parse((0, fs_1.readFileSync)(deviceProfileFile, "utf-8"));
            }
            catch (error) {
                console.log("The device profile file does not contain valid JSON " + error.toString());
                return;
            }
            const deviceProfileDto = deviceProfileFileData;
            let codecFileData;
            if (codecFile !== undefined) {
                if (!codecFile.toLowerCase().match(".js")) {
                    console.log("Error processing codec: The file must have a filename ending in .js");
                    return;
                }
                codecFileData = (0, fs_1.readFileSync)(codecFile, "utf-8");
                deviceProfileDto.payloadCodec = codecFileData;
            }
            if (deviceProfileFileData.hasOwnProperty("name") && deviceProfileFileData.hasOwnProperty("macVersion") &&
                deviceProfileFileData.hasOwnProperty("supportsJoin")) {
                base_api.v1DeviceprofilePost(deviceProfileDto).then((res) => {
                    console.log(`Device profile with name ${deviceProfileDto.name} successfully created.`);
                    if (res.data != "") {
                        console.log(res.data);
                    }
                }).catch((err) => {
                    new helper_functions_1.default().handleError(err);
                });
            }
            else {
                console.log("Name, mac version or supports join is missing from the JSON file passed.");
                return;
            }
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = Post;
Post.description = "Create a device profile.";
Post.examples = [
    "<%= config.bin %> <%= command.id %> --deviceProfile ./device-profile.json",
    "<%= config.bin %> <%= command.id %> --deviceProfile ./device-profile.json --codec ./device-profile-codec.js"
];
Post.flags = {
    deviceProfile: core_1.Flags.string({ char: "d", description: "File containing device profile data in json format.", required: true }),
    codec: core_1.Flags.string({ char: "c", description: "File containing the codec in JavaScript format.", required: false })
};
