"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class PostAppdataEncoded extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(PostAppdataEncoded).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const devEui = flags.devEui;
            const data = JSON.parse(flags.data);
            const base_api = new sigma_api_builder_1.default().buildApi("device");
            base_api.v1DeviceDevEuiAppdatamtencodedPost(devEui, data).then((res) => {
                if (res.data != "") {
                    console.log(res.data);
                }
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = PostAppdataEncoded;
PostAppdataEncoded.description = "Send encoded data to a LoraWan device.";
PostAppdataEncoded.examples = [
    "<%= config.bin %> <%= command.id %> --devEui 00000000000019 --data " +
        "\"[{\\\"port\\\": 4200, \\\"data\\\": \\\"A158EBF\\\"}, {\\\"port\\\": 4200, \\\"data\\\": \\\"03855DBF\\\"}]\""
];
PostAppdataEncoded.flags = {
    devEui: core_1.Flags.string({ char: "d", description: "DevEui of device", required: true }),
    data: core_1.Flags.string({
        description: "Data to send, as a stringified JSON array of objects of format: { port: number, data: string }",
        required: true
    })
};
