"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class PostAppdataUnencoded extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(PostAppdataUnencoded).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const devEui = flags.devEui;
            const data = JSON.parse(flags.data);
            const base_api = new sigma_api_builder_1.default().buildApi("device");
            base_api.v1DeviceDevEuiAppdatamtPost(devEui, data).then((res) => {
                if (res.data != "") {
                    console.log(res.data);
                }
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = PostAppdataUnencoded;
PostAppdataUnencoded.description = "Send data to a device. The data will be encoded by the codec defined in the " +
    "Device Profile of the target device.";
PostAppdataUnencoded.examples = [
    "<%= config.bin %> <%= command.id %> --devEui 00000000000019 --data \"[{\\\"ledColor\\\": \\\"green\\\"}, {\\\"ledEnabled\\\": true}, {\\\"ledFrequency\\\": \\3.5\\\"}]\""
];
PostAppdataUnencoded.flags = {
    devEui: core_1.Flags.string({ char: "d", description: "DevEui of device.", required: true }),
    data: core_1.Flags.string({
        description: "Data to send as a stringified array of JSON objects.",
        required: true
    })
};
