"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class Post extends core_1.Command {
    async run() {
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("device");
        try {
            await this.parse(Post).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const name = flags.name;
            const devEui = flags.devEui;
            const appKey = flags.appKey;
            const appSKey = flags.appSKey;
            const nwkSKey = flags.nwkSKey;
            const devAddress = flags.devAddress;
            const tags = flags.tags;
            const deviceProfileName = flags.deviceProfileName;
            const createDeviceDto = {
                name: name,
                devEui: devEui,
                deviceProfileName: deviceProfileName,
                appKey: appKey
            };
            if (nwkSKey) {
                createDeviceDto.nwkSKey = nwkSKey;
            }
            if (appSKey) {
                createDeviceDto.appSkey = appSKey;
            }
            if (devAddress) {
                createDeviceDto.devAddress = devAddress;
            }
            if (tags) {
                createDeviceDto.tags = tags;
            }
            if (nwkSKey) {
                if (!appSKey) {
                    console.log("It looks like you're trying to create a device in ABP mode. An appskey is required for this. Please set the --AppSKey flag.");
                }
            }
            base_api.v1DevicePost(createDeviceDto).then(() => {
                console.log(`Device with name ${name} and DevEUI ${devEui} successfully created.`);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = Post;
Post.description = "Create a new device.";
Post.examples = [
    "For OTAA: <%= config.bin %> <%= command.id %> --name NameOfNewDevice --devEui DevEuiOfNewDevice --appKey AppKeyOfNewDevice --deviceProfileName NameOfDeviceProfile",
    "For ABP: <%= config.bin %> <%= command.id %> --name NameOfNewDevice --devEui DevEuiOfNewDevice --appSKey AppKeyOfNewDevice --nwkSKey NwkSKeyOfNewDevice --deviceProfileName NameOfDeviceProfile",
    "Optional flags: <%= config.bin %> <%= command.id %> --name NameOfNewDevice --devEui DevEuiOfNewDevice --appKey AppKeyOfNewDevice --deviceProfileName NameOfDeviceProfile" +
        "--devAddress DevAddressOfNewDevice --tags \"{}\""
];
Post.flags = {
    name: core_1.Flags.string({ char: "n", description: "Name of new device.", required: true }),
    devEui: core_1.Flags.string({ description: "DevEUI of new device.", required: true }),
    appKey: core_1.Flags.string({ description: "AppKey of new device." }),
    appSKey: core_1.Flags.string({ description: "AppSKey for new device if activation mode is ABP." }),
    nwkSKey: core_1.Flags.string({ description: "NwkSKey of new device." }),
    devAddress: core_1.Flags.string({ description: "DevAddress of new device." }),
    tags: core_1.Flags.string({ description: "Tags given to new device." }),
    deviceProfileName: core_1.Flags.string({ description: "Device profile name for new device.", required: true })
};
