"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class PutProfile extends core_1.Command {
    async run() {
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("device");
        try {
            await this.parse(PutProfile).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const devEui = flags.devEui;
            const deviceProfileName = flags.deviceProfileName;
            let updateDeviceDto = { "deviceProfileName": deviceProfileName };
            base_api.v1DeviceDevEuiPut(devEui, updateDeviceDto).then((res) => {
                console.log(`Device profile with name ${deviceProfileName} successfully added to device with DevEUI ${devEui}.`);
                console.log(res.data);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = PutProfile;
PutProfile.description = "Update a device with a new device profile.";
PutProfile.examples = [
    "<%= config.bin %> <%= command.id %> --devEui DevEuiOfDeviceToUpdate --deviceProfileName NameOfDeviceProfileToAdd"
];
PutProfile.flags = {
    devEui: core_1.Flags.string({ char: "d", description: "DevEUI of device to update.", required: true }),
    deviceProfileName: core_1.Flags.string({
        char: "n",
        description: "Name of device profile to put on device.",
        required: true
    })
};
