"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class AddDeviceProfile extends core_1.Command {
    async run() {
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("k-cell");
        try {
            await this.parse(AddDeviceProfile).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const serialNumber = flags.serialNumber;
            const deviceProfileName = flags.deviceProfileName;
            let deviceProfiles = [];
            deviceProfiles.push(deviceProfileName);
            const addDeviceProfileNames = {
                "deviceProfileNames": deviceProfiles
            };
            base_api.v1KcellSerialNumberPost(serialNumber, addDeviceProfileNames).then(() => {
                console.log(`Device profile with name ${deviceProfileName} successfully added to cell with serial number ${serialNumber}.`);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = AddDeviceProfile;
AddDeviceProfile.description = "add a device profile to a K-Cell";
AddDeviceProfile.examples = [
    "<%= config.bin %> <%= command.id %> --serialNumber SerialNumberOfKCellToAddTo --deviceProfileName DeviceProfileNameToAdd"
];
AddDeviceProfile.flags = {
    serialNumber: core_1.Flags.string({ char: "s", description: "Serial number of K-Cell.", required: true }),
    deviceProfileName: core_1.Flags.string({ char: "d", description: "Device profile to add.", required: true })
};
