"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class DeleteDeviceProfile extends core_1.Command {
    async run() {
        var _a;
        let flags;
        try {
            await this.parse(DeleteDeviceProfile).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const serialNumber = flags.serialNumber;
            const deviceProfileDelete = flags.deviceProfileDelete;
            const deviceProfileReplace = (_a = flags.deviceProfileReplace) !== null && _a !== void 0 ? _a : null;
            const base_api = new sigma_api_builder_1.default().buildApi("k-cell");
            let deleteDeviceProfileDto = {
                "nameOfProfileToDelete": deviceProfileDelete,
                "nameOfProfileToReplaceWith": deviceProfileReplace
            };
            base_api.v1KcellSerialNumberDeviceprofileDelete(serialNumber, deleteDeviceProfileDto).then(() => {
                if (deviceProfileReplace) {
                    console.log(`Device profile with name ${deviceProfileDelete} successfully deleted from cell with serial number ${serialNumber} and replaced with ${deviceProfileReplace}.`);
                    return;
                }
                console.log(`Device profile with name ${deviceProfileDelete} successfully deleted from cell with serial number ${serialNumber}.`);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = DeleteDeviceProfile;
DeleteDeviceProfile.description = "delete a device profile from a K-Cell";
DeleteDeviceProfile.examples = [
    "<%= config.bin %> <%= command.id %> --serialNumber SerialNumOfKCellToDeleteProfileFrom --deviceProfileDelete NameOfDeviceProfileToDelete",
    "<%= config.bin %> <%= command.id %> --serialNumber SerialNumOfKCellToDeleteProfileFrom --deviceProfileDelete NameOfDeviceProfileToDelete " +
        "--deviceProfileReplace NameOfDeviceProfileToReplace"
];
DeleteDeviceProfile.flags = {
    serialNumber: core_1.Flags.string({ char: "s", description: "Serial number of K-Cell.", required: true }),
    deviceProfileDelete: core_1.Flags.string({ char: "d", description: "Name of device profile to delete.", required: true }),
    deviceProfileReplace: core_1.Flags.string({ char: "r", description: "Name of device profile to replace with." })
};
