"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class Get extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(Get).then((res) => {
                flags = res.flags;
            }).catch(() => {
                throw new Error("Flag passed is not supported.");
            });
            const serialNumber = flags.serialNumber;
            const base_api = new sigma_api_builder_1.default().buildApi("k-cell");
            let api_call;
            if (serialNumber) {
                api_call = base_api.v1KcellSerialNumberGet(serialNumber);
            }
            else {
                api_call = base_api.v1KcellGet();
            }
            api_call.then((res) => {
                console.log(res.data);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            const error = err;
            console.log(error.message);
        }
    }
}
exports.default = Get;
Get.description = "Get all gateways. If serialNumber flag is set, get K-Cell by serial number.";
Get.examples = [
    "<%= config.bin %> <%= command.id %>",
    "<%= config.bin %> <%= command.id %> --serialNumber NameOfGatewayToGet"
];
Get.flags = {
    serialNumber: core_1.Flags.string({ char: "s", description: "Serial number of K-Cell." })
};
