"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class RequestStatus extends core_1.Command {
    async run() {
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("k-cell-operations");
        try {
            await this.parse(RequestStatus).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const serialNumber = flags.serialNumber;
            base_api.v1KcellSerialNumberOperationsRequeststatusPost(serialNumber).then(() => {
                console.log("Message has been queued to request status for the K-Cell");
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = RequestStatus;
RequestStatus.description = "Send request for information from your K-Cell such as battery level, charging status, etc.";
RequestStatus.examples = [
    "<%= config.bin %> <%= command.id %> --serialNumber 012346789"
];
RequestStatus.flags = {
    serialNumber: core_1.Flags.string({ char: "s", description: "Serial number of K-Cell.", required: true })
};
