"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class SetConfigTimings extends core_1.Command {
    async run() {
        var _a, _b, _c, _d;
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("k-cell");
        try {
            await this.parse(SetConfigTimings).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const serialNumber = flags.serialNumber;
            const appdataUplinkPeriod = (_a = flags.appdataUplink) !== null && _a !== void 0 ? _a : parseInt(flags.appdataUplink, 10);
            const statusUpdatePeriod = (_b = flags.statusUpdate) !== null && _b !== void 0 ? _b : parseInt(flags.statusUpdate, 10);
            const housekeepingUpdatePeriod = (_c = flags.housekeepingUpdate) !== null && _c !== void 0 ? _c : parseInt(flags.housekeepingUpdate, 10);
            const mtPollingPeriod = (_d = flags.mtPolling) !== null && _d !== void 0 ? _d : parseInt(flags.mtPolling, 10);
            const payload = {
                appdataUplinkPeriod: appdataUplinkPeriod,
                statusUpdatePeriod: statusUpdatePeriod,
                housekeepingUpdatePeriod: housekeepingUpdatePeriod,
                mtPollingPeriod: mtPollingPeriod
            };
            base_api.v1KcellSerialNumberConfigTimingsPost(serialNumber, payload).then(() => {
                console.log("Message has been queued to change message timings on the K-Cell");
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = SetConfigTimings;
SetConfigTimings.description = "Set frequency of status messages for a K-Cell.";
SetConfigTimings.examples = [
    "<%= config.bin %> <%= command.id %> " +
        "--serialNumber 012346789 --appdataUplink 120 --statusUpdate 60 --housekeepingUpdate 60 --mtPolling 90"
];
SetConfigTimings.flags = {
    serialNumber: core_1.Flags.string({ char: "s", description: "Serial number of K-Cell.", required: true }),
    appdataUplink: core_1.Flags.string({ char: "a", description: "Frequency of App-data Uplink messages.", required: false }),
    statusUpdate: core_1.Flags.string({ char: "t", description: "Frequency of Status Update messages.", required: false }),
    housekeepingUpdate: core_1.Flags.string({ char: "h", description: "Frequency of Housekeeping messages.", required: false }),
    mtPolling: core_1.Flags.string({ char: "m", description: "Frequency that cell polls for new MT packets.", required: false })
};
