"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class Get extends core_1.Command {
    async run() {
        let flags;
        try {
            await this.parse(Get).then((res) => {
                flags = res.flags;
            }).catch(() => {
                throw new Error("Flag passed is not supported.");
            });
            const name = flags.name;
            const secret = flags.secret;
            const base_api = new sigma_api_builder_1.default().buildApi("webhook");
            let api_call;
            if (name && secret) {
                api_call = base_api.v1WebhookNameSecretGet(name);
            }
            else if (name) {
                api_call = base_api.v1WebhookNameGet(name);
            }
            else {
                api_call = base_api.v1WebhookGet();
            }
            api_call.then((res) => {
                console.log(res.data);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            const error = err;
            console.log(error.message);
        }
    }
}
exports.default = Get;
Get.description = "Get all webhooks. If name flag is set, get webhook by name.";
Get.examples = [
    "<%= config.bin %> <%= command.id %>",
    "<%= config.bin %> <%= command.id %> --name NameOfWebhookToGet"
];
Get.flags = {
    name: core_1.Flags.string({ char: "n", description: "Name of webhook to get" }),
    secret: core_1.Flags.boolean({ char: "s", description: "Boolean flag, set true to request secret." })
};
