"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const sigma_api_builder_1 = require("../../config/sigma-api-builder");
const helper_functions_1 = require("../../config/helper-functions");
class Post extends core_1.Command {
    async run() {
        let flags;
        const base_api = new sigma_api_builder_1.default().buildApi("webhook");
        try {
            await this.parse(Post).then((res) => {
                flags = res.flags;
            }).catch((err) => {
                throw new Error(err);
            });
            const name = flags.name;
            const deploymentName = flags.deploymentName;
            const destinationUrl = flags.destinationUrl;
            const hmacAuth = flags.hmacAuth;
            const createWebhookDto = {
                "name": name, "deploymentName": deploymentName,
                "destinationUrl": destinationUrl, "includeHmacAuth": hmacAuth
            };
            base_api.v1WebhookPost(createWebhookDto).then((res) => {
                console.log(`Webhook with name ${name} and destination url ${destinationUrl} successfully created.`);
                console.log(res.data);
            }).catch((err) => {
                new helper_functions_1.default().handleError(err);
            });
        }
        catch (err) {
            console.log(err.message);
        }
    }
}
exports.default = Post;
Post.description = "Create a webhook.";
Post.examples = [
    "<%= config.bin %> <%= command.id %> --name NewWebhookName --deploymentName NameOfDeployment " +
        "--destinationUrl NewDestinationUrl",
    "<%= config.bin %> <%= command.id %> --name NewWebhookName --deploymentName NameOfDeployment " +
        "--destinationUrl NewDestinationUrl --hmacAuth"
];
Post.flags = {
    name: core_1.Flags.string({ char: "n", description: "New webhook name.", required: true }),
    deploymentName: core_1.Flags.string({ description: "Name of deployment to add webhook to.", required: true }),
    destinationUrl: core_1.Flags.string({ description: "Destination url of webhook.", required: true }),
    hmacAuth: core_1.Flags.boolean({ char: "h", description: "Destination url of webhook." })
};
